#!/usr/bin/env sh

set -e

seed_es6() {
  if [ -z "$ES_HOST" ]; then
    echo >&2 "Must define ES_HOST as <scheme>:<hostname>:<port>"
    exit 2
  fi
  echo "****IS_FEATURE branch= $IS_FEATURE"
  if [[ "$IS_FEATURE" != "true" ]]; then
    echo "Waiting for 60 seconds to give ES-6 enough time to boot up on $ES_HOST:$ES_PORT..."
    sleep 60 # make sure ES-6 has had enough time to start otherwise indices might not get initialized correctly
  else
    echo "Waiting for a few seconds to give ES-6 enough time to boot up on $ES_HOST:$ES_PORT..."
    sleep 10 # make sure ES-5 has had enough time to start otherwise indices might not get initialized correctly
    while [[ "$(curl -s -o /dev/null -w ''%{http_code}'' $ES_HOST:$ES_PORT)" != "200" ]]; do
      echo "Still waiting on ES-6 to boot up..."
      sleep 5
    done
  fi

  echo "Creating ES-6 indexes and templates for ${ES_HOST}"

  cd /src/es6

  if [[ -z "${REGION}" ]]; then
    livequery_alias_exists=`python3 ./managed-es/check_alias_exists.py -e ${ES_HOST} -a 'a_livequery'`
    livequerytemplate_alias_exists=`python3 ./managed-es/check_alias_exists.py -e ${ES_HOST} -a 'a_livequerytemplate'`

    echo "Value of livequery_alias_exists=${livequery_alias_exists}"
    echo "Value of livequerytemplate_alias_exists=${livequerytemplate_alias_exists}"

    if [[ "${livequery_alias_exists}" != "True" ]]; then
     echo "Creating index livequery as alias (a_livequery) does not exist..."
     python3 ./managed-es/create_new_index.py -e ${ES_HOST} -i 'livequery' -m './mappings/livequery_mappings.json' -s './settings/livequery_settings.json'
     python3 ./managed-es/switch_index_alias.py -e ${ES_HOST} -i 'livequery' -o 'livequery' -a 'a_livequery'
    fi

    if [[ "${livequerytemplate_alias_exists}" != "True" ]]; then
     echo "Creating index livequerytemplate as alias (a_livequerytemplate) does not exist..."
     python3 ./managed-es/create_new_index.py -e ${ES_HOST} -i 'livequerytemplate' -m './mappings/livequerytemplate_mappings.json' -s './settings/livequerytemplate_settings.json'
     python3 ./managed-es/switch_index_alias.py -e ${ES_HOST} -i 'livequerytemplate' -o 'livequerytemplate' -a 'a_livequerytemplate'
    fi
    python3 ./managed-es/create_index_template.py -e ${ES_HOST} -i 'livequeryresult' -m './mappings/livequeryresult_mappings.json' -s './settings/livequeryresult_settings.json'
    python3 ./managed-es/create_index_template.py -e ${ES_HOST} -i 'livequerydevicesummaries' -m './mappings/livequerydevicesummaries_mappings.json' -s './settings/livequerydevicesummaries_settings.json'
  else
    livequery_alias_exists=`python3 ./managed-es/check_alias_exists.py -e ${ES_HOST} -a 'a_livequery' -r ${REGION}`
    livequerytemplate_alias_exists=`python3 ./managed-es/check_alias_exists.py -e ${ES_HOST} -a 'a_livequerytemplate' -r ${REGION}`

    if [[ "${livequery_alias_exists}" != "True" ]]; then
      python3 ./managed-es/create_new_index.py -e ${ES_HOST} -i 'livequery' -m './mappings/livequery_mappings.json' -s './settings/livequery_settings.json' -r ${REGION}
      python3 ./managed-es/switch_index_alias.py -e ${ES_HOST} -i 'livequery' -o 'livequery' -a 'a_livequery' -r ${REGION}
    fi

    if [[ "${livequerytemplate_alias_exists}" != "True" ]]; then
      python3 ./managed-es/create_new_index.py -e ${ES_HOST} -i 'livequerytemplate' -m './mappings/livequerytemplate_mappings.json' -s './settings/livequerytemplate_settings.json' -r ${REGION}
      python3 ./managed-es/switch_index_alias.py -e ${ES_HOST} -i 'livequerytemplate' -o 'livequerytemplate' -a 'a_livequerytemplate' -r ${REGION}
    fi
    python3 ./managed-es/create_index_template.py -e ${ES_HOST} -i 'livequeryresult' -m './mappings/livequeryresult_mappings.json' -s './settings/livequeryresult_settings.json' -r ${REGION}
    python3 ./managed-es/create_index_template.py -e ${ES_HOST} -i 'livequerydevicesummaries' -m './mappings/livequerydevicesummaries_mappings.json' -s './settings/livequerydevicesummaries_settings.json' -r ${REGION}
  fi
}

seed_es5() {
  if [ -z "$ES_HOST" ]; then
    echo >&2 "Must define ES_HOST as <scheme>:<hostname>:<port>"
    exit 2
  fi

  echo "Waiting for a few seconds to give ES-5 enough time to boot up on $ES_HOST:$ES_PORT..."
  sleep 10 # make sure ES-5 has had enough time to start otherwise indices might not get initialized correctly
  while [[ "$(curl -s -o /dev/null -w ''%{http_code}'' $ES_HOST:$ES_PORT)" != "200" ]]; do
    echo "Still waiting on ES-5 to boot up..."
    sleep 5
  done

  echo "ES-5 is ready!!!"

  echo "Creating ES-5 indexes and templates for ${ES_HOST}"
  cd /src/es5

  if [[ -z "${REGION}" ]]; then
    echo "Creating ES-5 indexes and templates without region information..."

    livequery_alias_exists=`python3 ./managed-es5/check_alias_exists.py -e ${ES_HOST} -a 'a_livequery'`
    livequerytemplate_alias_exists=`python3 ./managed-es5/check_alias_exists.py -e ${ES_HOST} -a 'a_livequerytemplate'`

    echo "Value of livequery_alias_exists=${livequery_alias_exists}"
    echo "Value of livequerytemplate_alias_exists=${livequerytemplate_alias_exists}"

    if [[ "${livequery_alias_exists}" != "True" ]]; then
      echo "Creating index livequery as alias (a_livequery) does not exist..."
      python3 ./managed-es5/create_new_index.py -e ${ES_HOST} -i 'livequery' -m './mappings/livequery_mappings.json' -s './settings/livequery_settings.json'
      python3 ./managed-es5/switch_index_alias.py -e ${ES_HOST} -i 'livequery' -o 'livequery' -a 'a_livequery'
    fi

    if [[ "${livequerytemplate_alias_exists}" != "True" ]]; then
      echo "Creating index livequerytemplate as alias (a_livequerytemplate) does not exist..."
      python3 ./managed-es5/create_new_index.py -e ${ES_HOST} -i 'livequerytemplate' -m './mappings/livequerytemplate_mappings.json' -s './settings/livequerytemplate_settings.json'
      python3 ./managed-es5/switch_index_alias.py -e ${ES_HOST} -i 'livequerytemplate' -o 'livequerytemplate' -a 'a_livequerytemplate'
    fi

    python3 ./managed-es5/create_index_template.py -e ${ES_HOST} -i 'livequeryresult' -m './mappings/livequeryresult_mappings.json' -s './settings/livequeryresult_settings.json'
    python3 ./managed-es5/create_index_template.py -e ${ES_HOST} -i 'livequerydevicesummaries' -m './mappings/livequerydevicesummaries_mappings.json' -s './settings/livequerydevicesummaries_settings.json'

  else
    echo "Creating ES-5 indexes and templates with region information..."

    livequery_alias_exists=`python3 ./managed-es5/check_alias_exists.py -e ${ES_HOST} -a 'a_livequery' -r ${REGION}`
    livequerytemplate_alias_exists=`python3 ./managed-es5/check_alias_exists.py -e ${ES_HOST} -a 'a_livequerytemplate' -r ${REGION}`

    if [[ "${livequery_alias_exists}" != "True" ]]; then
      python3 ./managed-es5/create_new_index.py -e ${ES_HOST} -i 'livequery' -m './mappings/livequery_mappings.json' -s './settings/livequery_settings.json' -r ${REGION}
      python3 ./managed-es5/switch_index_alias.py -e ${ES_HOST} -i 'livequery' -o 'livequery' -a 'a_livequery' -r ${REGION}
    fi

    if [[ "${livequerytemplate_alias_exists}" != "True" ]]; then
      python3 ./managed-es5/create_new_index.py -e ${ES_HOST} -i 'livequerytemplate' -m './mappings/livequerytemplate_mappings.json' -s './settings/livequerytemplate_settings.json' -r ${REGION}
      python3 ./managed-es5/switch_index_alias.py -e ${ES_HOST} -i 'livequerytemplate' -o 'livequerytemplate' -a 'a_livequerytemplate' -r ${REGION}
    fi

    python3 ./managed-es5/create_index_template.py -e ${ES_HOST} -i 'livequeryresult' -m './mappings/livequeryresult_mappings.json' -s './settings/livequeryresult_settings.json' -r ${REGION}
    python3 ./managed-es5/create_index_template.py -e ${ES_HOST} -i 'livequerydevicesummaries' -m './mappings/livequerydevicesummaries_mappings.json' -s './settings/livequerydevicesummaries_settings.json' -r ${REGION}

  fi
}

seed_mockaws() {
  if [ -z "$LOCALSTACK_HOST" ]; then
    echo >&2 "Must define LOCALSTACK_HOST"
    exit 3
  fi

  echo "Creating mockaws resources for ${LOCALSTACK_HOST}"

  cd /config
  # remember to set LOCALSTACK_HOST env variable
  python3 /config/init.py
}

seed_mockpsc() {
  if [ -z "$PSC_MOCK_SERVICE_HOST" ]; then
    echo >&2 "Must define PSC_MOCK_SERVICE_HOST"
    exit 4
  fi

  echo "Creating sample data for ${PSC_MOCK_SERVICE_HOST}"

  curl -X POST -H "Content-Type: application/json" -d @"/sample-data/psc-mock-service.json" "${PSC_MOCK_SERVICE_HOST}/create_sample_data"
}

upload_tau_queries_s3() {
  # This script is used as entrypoint in Dockerfile-init to upload TAU query templates to s3 in GovCloud

  echo "Publishing templates to ${S3_BUCKET_NAME}..."

  cd /src

  if [[ -z "${S3_ENDPOINT_URL}" ]]; then
    cmd_prefix="aws s3 cp --content-type json --sse AES256 --region ${REGION}"
  else
    cmd_prefix="aws s3 cp --content-type json --no-verify-ssl --region ${REGION} --endpoint-url ${S3_ENDPOINT_URL}"
  fi

  echo "Command prefix is set to ${cmd_prefix}"

  eval "$cmd_prefix ./vdp/resources/v1.json s3://${S3_BUCKET_NAME}/"

  echo "Finished uploading tau query templates to ${S3_BUCKET_NAME}!"
}

while test $# -gt 0; do
  case "$1" in
  mockaws)
    seed_mockaws
    ;;
  mockpsc)
    seed_mockpsc
    ;;
  tauqueries)
    upload_tau_queries_s3
    ;;
  es6)
    seed_es6
    ;;
  es5)
    seed_es5
    ;;
  *)
    echo >&2 "Invalid option"
    exit 1
    ;;
  esac
  shift
done
